# File-Name:       untitled                
# Date:            2013-04-28                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:
# Packages Used:              
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac

require("reshape")
require("ggplot2")
  require(quantmod)
  library(astsa)

  library(foreign)
  library(mFilter)
  library(MASS)
  library(tseries)
  library(urca)
  library(MSBVAR)


  ###Reading the Data into R
  unscaled<-read.dta(file="2nd_Gaza_Conflict.dta")

  #summarizing the data
  summary(unscaled)

  #Israeli Defense Foces Twitter Feed
  IDF<-log(unscaled$idf_twitter+.1)
  #Hamas Twiter Feed
  AQB<-log(unscaled$hamas_twitter+.1)
  #Israel 2 Hamas Conflict Intensity
  I2H<-log(unscaled$combined_i2h+.1)
  #Hamas 2 Israel Conflict Intensity
  H2I<-log(unscaled$combined_h2i+.1)
  #Egypt Pressure
  Egypt<-log(unscaled$egypt_pressure+.1)
  #US Pressure
  US<-log(unscaled$us_pressure+.1)
  #UN Pressure 
  UN<-log(unscaled$un_pressure+.1)


  
  
##Hashtag data
hashtag_data<-read.csv(file="merged_hashtag.csv" ,head=TRUE,sep=",")
summary(hashtag_data)
gaza_under<-hashtag_data$gaza_under_attack
israel_under<-hashtag_data$israel_under_fire

##Israel Under Fire Predicting Gaza Under Attack
lag2.plot(israel_under, gaza_under, max.lag = 12, corr = TRUE, smooth = TRUE)

##Gaza Under Attack Predicting Israel Under Fire
lag2.plot( gaza_under, israel_under, max.lag = 12, corr = TRUE, smooth = TRUE)

lag2.plot( UN, US, max.lag = 12, corr = TRUE, smooth = TRUE)

##Reading in Hashtag data


###Time Series Plots
plot(ts(unscaled$idf_twitter, frequency=24), ann=FALSE)
title(xlab="Time in Days", ylab="IDF Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$hamas_twitter, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="AQB Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$combined_i2h, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="I2H Conflict Intensity", cex.lab=1.4)
plot(ts(unscaled$combined_h2i, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="H2I Conflict Intensity", cex.lab=1.4)
plot(ts(hashtag_data$gaza_under_attack, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#GazaUnderAttack", cex.lab=1.4)
plot(ts(hashtag_data$israel_under_fire, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#IsraelUnderFire", cex.lab=1.4)



f<-cbind(gaza_under, israel_under)

#Decomposing things
plot(decompose(ts(hashtag_data$gaza_under_attack, frequency=24)), xlab="#GazaUnderAttack  (time in days)")
plot(decompose(ts(hashtag_data$israel_under_fire, frequency=24)), xlab="#IsraelUnderFire  (time in days)")

plot(decompose(ts(hashtag_data$gaza_under_attack-hashtag_data$israel_under_fire, frequency=24)), xlab="#GazaUnderAttack  (time in days)")

#Disentangling the effects
gaza_hash_ts<-ts(log(hashtag_data$gaza_under_attack+.1), frequency=24)
israel_hash_ts<-ts(log(hashtag_data$israel_under_fire+.1), frequency=24)

#Decomposed the data
Gaza_Hash_d<-log(hashtag_data$gaza_under_attack+.1)-decompose(gaza_hash_ts)$seasonal
Israel_Hash_d<-log(hashtag_data$israel_under_fire+.1)-decompose(israel_hash_ts)$seasonal

IDF_ts<-ts(IDF, frequency=24)
AQB_ts<-ts(AQB, frequency=24)
I2H_ts<-ts(I2H, frequency=24)
H2I_ts<-ts(H2I, frequency=24)
Egypt_ts<-ts(Egypt, frequency=24)
US_ts<-ts(US, frequency=24)
UN_ts<-ts(UN, frequency=24)

###Removing the 24 hours seasonality due the news cycle
IDF_d<-IDF-decompose(IDF_ts)$seasonal
AQB_d<-AQB-decompose(AQB_ts)$seasonal
I2H_d<-I2H-decompose(I2H_ts)$seasonal
H2I_d<-H2I-decompose(H2I_ts)$seasonal
Egypt_d<-Egypt-decompose(Egypt_ts)$seasonal
US_d<-US-decompose(US_ts)$seasonal
UN_d<-UN-decompose(UN_ts)$seasonal



plot(Gaza_Hash_d)
plot(Israel_Hash_d)
#Non_Decomposed_data
Gaza_Hash<-log(hashtag_data$gaza_under_attack+.1)
Israel_Hash<-log(hashtag_data$israel_under_fire+.1)

plot(ts(Gaza_Hash))
plot(ts(Israel_Hash))

##Adding seasonal
seasonal_dummies<-ts(hashtag_data$peak_hours)


#Joining the time series
israel_gaza<-cbind(H2I, I2H, IDF, AQB, UN, Egypt, US, Gaza_Hash_d, Israel_Hash_d)


non_detrended_israel_gaza<-cbind(H2I, I2H, IDF, AQB, Gaza_Hash, Israel_Hash)

##Full Data (not adjusted for seasonality)
second_gaza<-ts(israel_gaza)
second_gaza_nd<-ts(non_detrended_israel_gaza)

#Variable Lag Test
var.lag.specification(second_gaza,lagmax=12)

#Granger Test
granger.test(second_gaza, 5)
summary(lm(Israel_Hash~seasonal_dummies))

##Restriction A0

###Baseline Model (H2I and I2H react contemp to each other)
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,0,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

baseline<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


##IDF Model
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

idf_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##AQB Model
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(1,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,0,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

aqb_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##Both Model
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(1,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

both_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

####Mediator Models### (IDF Conflict A0 nested within)

#Mediator Both (both AQB and IDF respond contemp to all int'l mediators)

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,1,1,1,0,0,0,0)
egypt_i<-      c(0,0,1,1,0,1,0,0,0)
us_i<-         c(0,0,1,1,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

mediator_both<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


#Mediator IDF (only IDF respond contemp to int'l mediators)
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,1,0,1,0,0,0,0)
egypt_i<-      c(0,0,1,0,0,1,0,0,0)
us_i<-         c(0,0,1,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

mediator_idf<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



#Mediator AQB
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,1,1,0,0,0,0)
egypt_i<-      c(0,0,0,1,0,1,0,0,0)
us_i<-         c(0,0,0,1,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

mediator_aqb<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



#Biased Mediator

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,1,0,1,0,0,0)
us_i<-         c(0,0,1,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

mediator_biased<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



####Running the BSVAR#####

####Baseline Model##########################################
set.seed(67986)
baseline_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=baseline)

##Getting the Sign
sign.baseline <- ifelse(sign(diag(baseline_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.baseline

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_baseline<- gibbs.A0(baseline_second_gaza.bvar, 10000, 20000)



fit_baseline<- posterior.fit(baseline_second_gaza.bvar, A0.posterior_baseline)
print(fit_baseline)


bsvar_baseline<- mc.irf(baseline_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_baseline, sign.list=sign.baseline)
plot(bsvar_baseline, probs=c(0.05,0.16,0.84,0.95))



###IDF Conflict

set.seed(67986)
idf_conflict_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=idf_conflict)

##Getting the Sign
sign.idf_conflict <- ifelse(sign(diag(idf_conflict_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.idf_conflict

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_idf_conflict<- gibbs.A0(idf_conflict_second_gaza.bvar, 10000, 20000)





fit_idf_conflict<- posterior.fit(idf_conflict_second_gaza.bvar, A0.posterior_idf_conflict)
print(fit_idf_conflict)


bsvar_idf_conflict<- mc.irf(idf_conflict_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_idf_conflict, sign.list=sign.idf_conflict)
plot(bsvar_idf_conflict, probs=c(0.05,0.16,0.84,0.95))



##AQB Conflict
set.seed(67986)
aqb_conflict_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=aqb_conflict)

##Getting the Sign
sign.aqb_conflict <- ifelse(sign(diag(aqb_conflict_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.aqb_conflict

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_aqb_conflict<- gibbs.A0(aqb_conflict_second_gaza.bvar, 10000, 20000)




fit_aqb_conflict<- posterior.fit(aqb_conflict_second_gaza.bvar, A0.posterior_aqb_conflict)
print(fit_aqb_conflict)


bsvar_aqb_conflict<- mc.irf(aqb_conflict_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_aqb_conflict, sign.list=sign.aqb_conflict)
plot(bsvar_aqb_conflict, probs=c(0.05,0.16,0.84,0.95))



###Both Conflict
set.seed(67986)
both_conflict_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=both_conflict)

##Getting the Sign
sign.both_conflict <- ifelse(sign(diag(both_conflict_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.both_conflict

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_both_conflict<- gibbs.A0(both_conflict_second_gaza.bvar, 10000, 20000)




fit_both_conflict<- posterior.fit(both_conflict_second_gaza.bvar, A0.posterior_both_conflict)
print(fit_both_conflict)


bsvar_both_conflict<- mc.irf(both_conflict_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_both_conflict, sign.list=sign.both_conflict)
plot(bsvar_both_conflict, probs=c(0.05,0.16,0.84,0.95))

#####Mediator Models##############################################

###Mediator Both####

set.seed(67986)
mediator_both_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=mediator_both)

##Getting the Sign
sign.mediator_both <- ifelse(sign(diag(mediator_both_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.mediator_both

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_mediator_both<- gibbs.A0(mediator_both_second_gaza.bvar, 10000, 20000)


fit_mediator_both<- posterior.fit(mediator_both_second_gaza.bvar, A0.posterior_mediator_both)
print(fit_mediator_both)


bsvar_mediator_both<- mc.irf(mediator_both_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_mediator_both, sign.list=sign.mediator_both)
plot(bsvar_mediator_both, probs=c(0.05,0.16,0.84,0.95))


###IDF Mediator###

set.seed(67986)
mediator_idf_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=mediator_idf)

##Getting the Sign
sign.mediator_idf <- ifelse(sign(diag(mediator_idf_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.mediator_idf

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_mediator_idf<- gibbs.A0(mediator_idf_second_gaza.bvar, 10000, 20000)


fit_mediator_idf<- posterior.fit(mediator_idf_second_gaza.bvar, A0.posterior_mediator_idf)
print(fit_mediator_idf)


bsvar_mediator_idf<- mc.irf(mediator_idf_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_mediator_idf, sign.list=sign.mediator_idf)
plot(bsvar_mediator_idf, probs=c(0.05,0.16,0.84,0.95))


###AQB Mediator###

set.seed(67986)
mediator_aqb_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=mediator_aqb)

##Getting the Sign
sign.mediator_aqb <- ifelse(sign(diag(mediator_aqb_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.mediator_aqb

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_mediator_aqb<- gibbs.A0(mediator_aqb_second_gaza.bvar, 10000, 20000)


fit_mediator_aqb<- posterior.fit(mediator_aqb_second_gaza.bvar, A0.posterior_mediator_aqb)
print(fit_mediator_aqb)


bsvar_mediator_aqb<- mc.irf(mediator_aqb_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_mediator_aqb, sign.list=sign.mediator_aqb)
plot(bsvar_mediator_aqb, probs=c(0.05,0.16,0.84,0.95))


##Biased Mediator###
set.seed(67986)
mediator_biased_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=mediator_biased)

##Getting the Sign
sign.mediator_biased <- ifelse(sign(diag(mediator_biased_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.mediator_biased

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_mediator_biased<- gibbs.A0(mediator_biased_second_gaza.bvar, 10000, 20000)


fit_mediator_biased<- posterior.fit(mediator_biased_second_gaza.bvar, A0.posterior_mediator_biased)
print(fit_mediator_biased)


bsvar_mediator_biased<- mc.irf(mediator_biased_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_mediator_biased, sign.list=sign.mediator_biased)
plot(bsvar_mediator_biased, probs=c(0.05,0.16,0.84,0.95))










###Comparing Posterior Fits

print(fit_baseline)

print(fit_idf_conflict)

print(fit_aqb_conflict)

print(fit_both_conflict)

print(fit_mediator_both)

print(fit_mediator_idf)

print(fit_mediator_aqb)

print(fit_mediator_biased)






