# File-Name:       untitled                
# Date:            2013-04-28                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:
# Packages Used:              
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac

require("reshape")
require("ggplot2")
  require(quantmod)
  library(astsa)

  library(foreign)
  library(mFilter)
  library(MASS)
  library(tseries)
  library(urca)
  library(MSBVAR)


  ###Reading the Data into R
  unscaled<-read.dta(file="2nd_Gaza_Conflict.dta")

  #summarizing the data
  summary(unscaled)

  #Israeli Defense Foces Twitter Feed
  IDF<-log(unscaled$idf_twitter+.1)
  #Hamas Twiter Feed
  AQB<-log(unscaled$hamas_twitter+.1)
  #Israel 2 Hamas Conflict Intensity
  I2H<-log(unscaled$combined_i2h+.1)
  #Hamas 2 Israel Conflict Intensity
  H2I<-log(unscaled$combined_h2i+.1)
  #Egypt Pressure
  Egypt<-log(unscaled$egypt_pressure+.1)
  #US Pressure
  US<-log(unscaled$us_pressure+.1)
  #UN Pressure 
  UN<-log(unscaled$un_pressure+.1)


  
  
##Hashtag data
hashtag_data<-read.csv(file="merged_hashtag.csv" ,head=TRUE,sep=",")
summary(hashtag_data)
gaza_under<-hashtag_data$gaza_under_attack
israel_under<-hashtag_data$israel_under_fire

##Israel Under Fire Predicting Gaza Under Attack
lag2.plot(israel_under, gaza_under, max.lag = 12, corr = TRUE, smooth = TRUE)

##Gaza Under Attack Predicting Israel Under Fire
lag2.plot( gaza_under, israel_under, max.lag = 12, corr = TRUE, smooth = TRUE)

lag2.plot( UN, US, max.lag = 12, corr = TRUE, smooth = TRUE)

##Reading in Hashtag data


###Time Series Plots
plot(ts(unscaled$idf_twitter, frequency=24), ann=FALSE)
title(xlab="Time in Days", ylab="IDF Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$hamas_twitter, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="AQB Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$combined_i2h, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="I2H Conflict Intensity", cex.lab=1.4)
plot(ts(unscaled$combined_h2i, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="H2I Conflict Intensity", cex.lab=1.4)
plot(ts(hashtag_data$gaza_under_attack, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#GazaUnderAttack", cex.lab=1.4)
plot(ts(hashtag_data$israel_under_fire, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#IsraelUnderFire", cex.lab=1.4)



f<-cbind(gaza_under, israel_under)

#Decomposing things
plot(decompose(ts(hashtag_data$gaza_under_attack, frequency=24)), xlab="#GazaUnderAttack  (time in days)")
plot(decompose(ts(hashtag_data$israel_under_fire, frequency=24)), xlab="#IsraelUnderFire  (time in days)")

plot(decompose(ts(hashtag_data$gaza_under_attack-hashtag_data$israel_under_fire, frequency=24)), xlab="#GazaUnderAttack  (time in days)")

#Disentangling the effects
gaza_hash_ts<-ts(log(hashtag_data$gaza_under_attack+.1), frequency=24)
israel_hash_ts<-ts(log(hashtag_data$israel_under_fire+.1), frequency=24)

#Decomposed the data
Gaza_Hash_d<-log(hashtag_data$gaza_under_attack+.1)-decompose(gaza_hash_ts)$seasonal
Israel_Hash_d<-log(hashtag_data$israel_under_fire+.1)-decompose(israel_hash_ts)$seasonal

IDF_ts<-ts(IDF, frequency=24)
AQB_ts<-ts(AQB, frequency=24)
I2H_ts<-ts(I2H, frequency=24)
H2I_ts<-ts(H2I, frequency=24)
Egypt_ts<-ts(Egypt, frequency=24)
US_ts<-ts(US, frequency=24)
UN_ts<-ts(UN, frequency=24)

###Removing the 24 hours seasonality due the news cycle
IDF_d<-IDF-decompose(IDF_ts)$seasonal
AQB_d<-AQB-decompose(AQB_ts)$seasonal
I2H_d<-I2H-decompose(I2H_ts)$seasonal
H2I_d<-H2I-decompose(H2I_ts)$seasonal
Egypt_d<-Egypt-decompose(Egypt_ts)$seasonal
US_d<-US-decompose(US_ts)$seasonal
UN_d<-UN-decompose(UN_ts)$seasonal



plot(Gaza_Hash_d)
plot(Israel_Hash_d)
#Non_Decomposed_data
Gaza_Hash<-log(hashtag_data$gaza_under_attack+.1)
Israel_Hash<-log(hashtag_data$israel_under_fire+.1)

plot(ts(Gaza_Hash))
plot(ts(Israel_Hash))

##Adding seasonal
seasonal_dummies<-ts(hashtag_data$peak_hours)


#Joining the time series
israel_gaza<-cbind(H2I_d, I2H_d, IDF_d, AQB_d, UN_d, Egypt_d, US_d, Gaza_Hash_d, Israel_Hash_d)


non_detrended_israel_gaza<-cbind(H2I, I2H, IDF, AQB, Gaza_Hash, Israel_Hash)

##Full Data (not adjusted for seasonality)
second_gaza<-ts(israel_gaza)
second_gaza_nd<-ts(non_detrended_israel_gaza)

#Variable Lag Test
var.lag.specification(second_gaza,lagmax=12)

#Granger Test
granger.test(second_gaza, 5)
summary(lm(Israel_Hash~seasonal_dummies))

##Restriction A0

###Baseline Model (H2I and I2H react contemp to each other)
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,0,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

baseline<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


##IDF Model
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

idf_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##AQB Model
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(1,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,0,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

aqb_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##Both Model
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(1,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

both_conflict<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

####Mediator Models### (IDF Conflict A0 nested within)

#Mediator Both (both AQB and IDF respond contemp to all int'l mediators)

hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,1,1,1,0,0,0,0)
egypt_i<-      c(0,0,1,1,0,1,0,0,0)
us_i<-         c(0,0,1,1,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

mediator_both<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


#Mediator IDF (only IDF respond contemp to int'l mediators)
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,1,0,1,0,0,0,0)
egypt_i<-      c(0,0,1,0,0,1,0,0,0)
us_i<-         c(0,0,1,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

mediator_idf<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



#Mediator AQB
hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,1,1,0,0,0,0)
egypt_i<-      c(0,0,0,1,0,1,0,0,0)
us_i<-         c(0,0,0,1,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

mediator_aqb<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



#Biased Mediator

hamas_i<-      c(1,1,1,1,0,0,0,0,0)
israel_i<-     c(0,1,1,1,0,0,0,0,0)
idf_i<-        c(0,1,1,1,0,0,0,0,0)
aqb_i<-        c(1,1,1,1,0,0,0,0,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,1,0,1,0,0,0)
us_i<-         c(0,0,1,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,0)
israel_hash_i<-c(0,0,0,0,0,0,0,0,1)

mediator_biased<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

#####Hashtag Analysis (IDF Conflict A0)####

#Baseline Hashtag
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,0,0,1,1)
israel_hash_i<-c(0,0,0,0,0,0,0,1,1)

hashtag_baseline<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##Both IDF and AQB Respond to hashtag shocks
hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,1,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,1,0,0,0,1,1)

hashtag_both<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)

##Hashtag IDF Only

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,1,0,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

hashtag_idf<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


#Hashtag AQB Only

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,0,1,0,0,0,1,1)

hashtag_aqb<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)


#Hashtag Biased Audience

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

hashtag_biased<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)





#######Hashtag Models###################################

###Baseline Hashtag##
set.seed(67986)
hashtag_baseline_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_baseline)

##Getting the Sign
sign.hashtag_baseline <- ifelse(sign(diag(hashtag_baseline_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_baseline

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_baseline<- gibbs.A0(hashtag_baseline_second_gaza.bvar, 10000, 20000)


fit_hashtag_baseline<- posterior.fit(hashtag_baseline_second_gaza.bvar, A0.posterior_hashtag_baseline)
print(fit_hashtag_baseline)


bsvar_hashtag_baseline<- mc.irf(hashtag_baseline_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_baseline, sign.list=sign.hashtag_baseline)
plot(bsvar_hashtag_baseline, probs=c(0.05,0.16,0.84,0.95))


###Both Hashtag###
set.seed(67986)
hashtag_both_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_both)

##Getting the Sign
sign.hashtag_both <- ifelse(sign(diag(hashtag_both_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_both

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_both<- gibbs.A0(hashtag_both_second_gaza.bvar, 10000, 20000)


fit_hashtag_both<- posterior.fit(hashtag_both_second_gaza.bvar, A0.posterior_hashtag_both)
print(fit_hashtag_both)


bsvar_hashtag_both<- mc.irf(hashtag_both_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_both, sign.list=sign.hashtag_both)
plot(bsvar_hashtag_both, probs=c(0.05,0.16,0.84,0.95))



###IDF Hashtag###

set.seed(67986)
hashtag_idf_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_idf)

##Getting the Sign
sign.hashtag_idf <- ifelse(sign(diag(hashtag_idf_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_idf

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_idf<- gibbs.A0(hashtag_idf_second_gaza.bvar, 10000, 20000)


fit_hashtag_idf<- posterior.fit(hashtag_idf_second_gaza.bvar, A0.posterior_hashtag_idf)
print(fit_hashtag_idf)


bsvar_hashtag_idf<- mc.irf(hashtag_idf_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_idf, sign.list=sign.hashtag_idf)
plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84,0.95))


###AQB Hashtag###

set.seed(67986)
hashtag_aqb_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_aqb)

##Getting the Sign
sign.hashtag_aqb <- ifelse(sign(diag(hashtag_aqb_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_aqb

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_aqb<- gibbs.A0(hashtag_aqb_second_gaza.bvar, 10000, 20000)


fit_hashtag_aqb<- posterior.fit(hashtag_aqb_second_gaza.bvar, A0.posterior_hashtag_aqb)
print(fit_hashtag_aqb)


bsvar_hashtag_aqb<- mc.irf(hashtag_aqb_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_aqb, sign.list=sign.hashtag_aqb)
plot(bsvar_hashtag_aqb, probs=c(0.05,0.16,0.84,0.95))


###Biased Hashtag###
set.seed(67986)
hashtag_biased_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_biased)

##Getting the Sign
sign.hashtag_biased <- ifelse(sign(diag(hashtag_biased_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_biased

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_biased<- gibbs.A0(hashtag_biased_second_gaza.bvar, 10000, 20000)


fit_hashtag_biased<- posterior.fit(hashtag_biased_second_gaza.bvar, A0.posterior_hashtag_biased)
print(fit_hashtag_biased)


bsvar_hashtag_biased<- mc.irf(hashtag_biased_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_biased, sign.list=sign.hashtag_biased)
plot(bsvar_hashtag_biased, probs=c(0.05,0.16,0.84,0.95))

##############################################
##############################################








###Comparing Posterior Fits



print(fit_hashtag_baseline)

print(fit_hashtag_both)

print(fit_hashtag_idf)

print(fit_hashtag_aqb)

print(fit_hashtag_biased)






