# File-Name:       untitled                
# Date:            2013-04-28                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:
# Packages Used:              
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac

require("reshape")
require("ggplot2")
  require(quantmod)
  library(astsa)

  library(foreign)
  library(mFilter)
  library(MASS)
  library(tseries)
  library(urca)
  library(MSBVAR)


  ###Reading the Data into R
  unscaled<-read.dta(file="2nd_Gaza_Conflict_verbal_material.dta")

  #summarizing the data
  summary(unscaled)

  #Israeli Defense Foces Twitter Feed
  IDF<-log(unscaled$idf_twitter+.1)
  #Hamas Twiter Feed
  AQB<-log(unscaled$hamas_twitter+.1)
  #Israel 2 Hamas Conflict Intensity
  I2H_M<-log(unscaled$israel_material+.1)
  #Hamas 2 Israel Material Conflict
  H2I_M<-log(unscaled$hamas_material+.1)
  I2H_V<-log(unscaled$israel_verbal+.1)
  #Hamas 2 Israel Conflict Intensity
  H2I_V<-log(unscaled$hamas_verbal+.1)
  #Egypt Pressure
  Egypt<-log(unscaled$egypt_pressure+.1)
  #US Pressure
  US<-log(unscaled$us_pressure+.1)
  #UN Pressure 
  UN<-log(unscaled$un_pressure+.1)


  
  
##Hashtag data
hashtag_data<-read.csv(file="merged_hashtag.csv" ,head=TRUE,sep=",")
summary(hashtag_data)
gaza_under<-hashtag_data$gaza_under_attack
israel_under<-hashtag_data$israel_under_fire

##Israel Under Fire Predicting Gaza Under Attack
lag2.plot(israel_under, gaza_under, max.lag = 12, corr = TRUE, smooth = TRUE)

##Gaza Under Attack Predicting Israel Under Fire
lag2.plot( gaza_under, israel_under, max.lag = 12, corr = TRUE, smooth = TRUE)

lag2.plot( UN, US, max.lag = 12, corr = TRUE, smooth = TRUE)

##Reading in Hashtag data


###Time Series Plots
plot(ts(unscaled$idf_twitter, frequency=24), ann=FALSE)
title(xlab="Time in Days", ylab="IDF Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$hamas_twitter, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="AQB Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$israel_material, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="I2H Material Conflict Intensity", cex.lab=1.4)
plot(ts(unscaled$hamas_material, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="H2I Material Conflict Intensity", cex.lab=1.4)
plot(ts(hashtag_data$gaza_under_attack, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#GazaUnderAttack", cex.lab=1.4)
plot(ts(hashtag_data$israel_under_fire, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#IsraelUnderFire", cex.lab=1.4)



f<-cbind(gaza_under, israel_under)

#Decomposing things
plot(decompose(ts(hashtag_data$gaza_under_attack, frequency=24)), xlab="#GazaUnderAttack  (time in days)")
plot(decompose(ts(hashtag_data$israel_under_fire, frequency=24)), xlab="#IsraelUnderFire  (time in days)")

plot(decompose(ts(hashtag_data$gaza_under_attack-hashtag_data$israel_under_fire, frequency=24)), xlab="#GazaUnderAttack  (time in days)")

#Disentangling the effects
gaza_hash_ts<-ts(log(hashtag_data$gaza_under_attack+.1), frequency=24)
israel_hash_ts<-ts(log(hashtag_data$israel_under_fire+.1), frequency=24)

#Decomposed the data
Gaza_Hash_d<-log(hashtag_data$gaza_under_attack+.1)-decompose(gaza_hash_ts)$seasonal
Israel_Hash_d<-log(hashtag_data$israel_under_fire+.1)-decompose(israel_hash_ts)$seasonal

IDF_ts<-ts(IDF, frequency=24)
AQB_ts<-ts(AQB, frequency=24)
I2H_M_ts<-ts(I2H_M, frequency=24)
H2I_M_ts<-ts(H2I_M, frequency=24)
I2H_V_ts<-ts(I2H_V, frequency=24)
H2I_V_ts<-ts(H2I_V, frequency=24)
Egypt_ts<-ts(Egypt, frequency=24)
US_ts<-ts(US, frequency=24)
UN_ts<-ts(UN, frequency=24)

###Removing the 24 hours seasonality due the news cycle
IDF_d<-IDF-decompose(IDF_ts)$seasonal
AQB_d<-AQB-decompose(AQB_ts)$seasonal
I2H_M_d<-I2H_M-decompose(I2H_M_ts)$seasonal
H2I_M_d<-H2I_M-decompose(H2I_M_ts)$seasonal
I2H_V_d<-I2H_V-decompose(I2H_V_ts)$seasonal
H2I_V_d<-H2I_V-decompose(H2I_V_ts)$seasonal
Egypt_d<-Egypt-decompose(Egypt_ts)$seasonal
US_d<-US-decompose(US_ts)$seasonal
UN_d<-UN-decompose(UN_ts)$seasonal



plot(Gaza_Hash_d)
plot(Israel_Hash_d)
#Non_Decomposed_data
Gaza_Hash<-log(hashtag_data$gaza_under_attack+.1)
Israel_Hash<-log(hashtag_data$israel_under_fire+.1)

plot(ts(Gaza_Hash))
plot(ts(Israel_Hash))

##Adding seasonal
seasonal_dummies<-ts(hashtag_data$peak_hours)


#Joining the time series
israel_gaza<-cbind(H2I_V,H2I_M, I2H_V, I2H_M, IDF, AQB, UN, Egypt, US, Gaza_Hash_d, Israel_Hash_d)




##Full Data (not adjusted for seasonality)
second_gaza<-ts(israel_gaza)


#Variable Lag Test
var.lag.specification(second_gaza,lagmax=12)

#Granger Test
granger.test(second_gaza, 5)
summary(lm(Israel_Hash~seasonal_dummies))

##Restriction A0


##Hashtag IDF Only

hamas_v<-      c(1,1,1,1,1,1,0,0,0,0,1)
hamas_m<-      c(1,1,1,1,1,1,0,0,0,0,1)
israel_m<-     c(0,0,1,1,1,1,0,0,0,1,0)
israel_v<-     c(0,0,1,1,1,1,0,0,0,1,0)
idf_i<-        c(0,0,1,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,0,0,1,0,0,0,0,1,1)

hashtag_idf<-rbind(hamas_v, hamas_m,israel_v,israel_m,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



####Running the BSVAR#####





###IDF Hashtag### ###Flatter Prior

set.seed(67986)
hashtag_idf_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_idf)

##Getting the Sign
sign.hashtag_idf <- ifelse(sign(diag(hashtag_idf_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_idf

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_idf<- gibbs.A0(hashtag_idf_second_gaza.bvar, 10000, 50000)


###Log Marginal Density to beat -3843.722####
# hamas_i<-      c(1,1,1,1,0,0,0,0,1) #
# israel_i<-     c(0,1,1,1,0,0,0,1,0) #
# idf_i<-        c(0,1,1,1,0,0,0,0,1) #
# aqb_i<-        c(1,1,1,1,0,0,0,1,0) #
# un_i<-         c(0,0,0,0,1,0,0,0,0) #
# egypt_i<-      c(0,0,0,0,0,1,0,0,0) #
# us_i<-         c(0,0,0,0,0,0,1,0,0) #
# gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1) #
# israel_hash_i<-c(0,0,1,0,0,0,0,1,1) #

fit_hashtag_idf<- posterior.fit(hashtag_idf_second_gaza.bvar, A0.posterior_hashtag_idf)
print(fit_hashtag_idf)


dfev(hashtag_idf_second_gaza.bvar, A0 =hashtag_idf, 12)


bsvar_hashtag_idf<- mc.irf(hashtag_idf_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_idf, sign.list=sign.hashtag_idf)
plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84,0.95))


#Shock: Gaza Under Attack, Response: H2I_M (Hamas_Material) ,101

gaza2h_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,101]
gaza2h_m_irf
#Cumulative IRF
apply(gaza2h_m_irf,2,cumsum)


###IRF plots###
#Shock: Gaza Under Attack, Response: H2I_V (Hamas_Verbal) ,100

gaza2h_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,100]
gaza2h_v_irf
#Cumulative IRF
apply(gaza2h_v_irf,2,cumsum)

#Shock: Gaza Under Attack, Response: I2H_M (Israel_Material) ,103

gaza2i_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,103]
gaza2i_m_irf
#Cumulative IRF
apply(gaza2i_m_irf,2,cumsum)


#Shock: Gaza Under Attack, Response: I2H_V (Israel_Verbal) ,102

gaza2i_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,102]
gaza2i_v_irf
#Cumulative IRF
apply(gaza2i_v_irf,2,cumsum)

#Shock: Israel Under Fire, Response: H2I_M (Hamas_Material) ,112

israel2h_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,112]
israel2h_m_irf
#Cumulative IRF
apply(israel2h_m_irf,2,cumsum)


#Shock: Israel Under Fire, Response: H2I_V (Hamas_Verbal) ,111

israel2h_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,111]
israel2h_v_irf
#Cumulative IRF
apply(israel2h_v_irf,2,cumsum)


#Shock: Israel Under Fire, Response: I2H_M (Israel_Material) ,114

israel2i_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,114]
israel2i_m_irf
#Cumulative IRF
apply(israel2i_m_irf,2,cumsum)


#Shock: Israel Under Fire, Response: I2H_V (Israel_Verbal) ,113

israel2i_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,113]
israel2i_v_irf
#Cumulative IRF
apply(israel2i_v_irf,2,cumsum)

#Shock: UN, Response: H2I_M (Hamas_Material) ,68

un2h_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,68]
un2h_m_irf
#Cumulative IRF
apply(un2h_m_irf,2,cumsum)


#Shock: UN, Response: H2I_V (Hamas_Verbal) ,67

un2h_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,67]
un2h_v_irf
#Cumulative IRF
apply(un2h_v_irf,2,cumsum)


#Shock: UN, Response: I2H_M (Israel_Material) ,70

un2i_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,70]
un2i_m_irf
#Cumulative IRF
apply(un2i_m_irf,2,cumsum)


#Shock: UN, Response: I2H_V (Israel_Verbal) ,69

un2i_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,69]
un2i_v_irf
#Cumulative IRF
apply(un2i_v_irf,2,cumsum)

#Shock: Egypt, Response: H2I_M (Hamas_Material) ,79

egypt2h_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,79]
egypt2h_m_irf
#Cumulative IRF
apply(egypt2h_m_irf,2,cumsum)


#Shock: Egypt, Response: H2I_V (Hamas_Verbal) ,78

egypt2h_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,78]
egypt2h_v_irf
#Cumulative IRF
apply(egypt2h_v_irf,2,cumsum)


#Shock: Egypt, Response: I2H_M (Israel_Material) ,81

egypt2i_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,81]
egypt2i_m_irf
#Cumulative IRF
apply(egypt2i_m_irf,2,cumsum)


#Shock: Egypt, Response: I2H_V (Israel_Verbal) ,80

egypt2i_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,80]
egypt2i_v_irf
#Cumulative IRF
apply(egypt2i_v_irf,2,cumsum)

#Shock: US, Response: H2I_M (Hamas_Material) ,90

us2h_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,90]
us2h_m_irf
#Cumulative IRF
apply(us2h_m_irf,2,cumsum)


#Shock: US, Response: H2I_V (Hamas_Verbal) ,89

us2h_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,89]
us2h_v_irf
#Cumulative IRF
apply(us2h_v_irf,2,cumsum)


#Shock: US, Response: I2H_M (Israel_Material) ,92

us2i_m_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,92]
us2i_m_irf
#Cumulative IRF
apply(us2i_m_irf,2,cumsum)


#Shock: US, Response: I2H_V (Israel_Verbal) ,91

us2i_v_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,91]
us2i_v_irf
#Cumulative IRF
apply(us2i_v_irf,2,cumsum)




