# File-Name:       untitled                
# Date:            2013-04-28                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:
# Packages Used:              
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac

require("reshape")
require("ggplot2")
  require(quantmod)
  library(astsa)

  library(foreign)
  library(mFilter)
  library(MASS)
  library(tseries)
  library(urca)
  library(MSBVAR)


  ###Reading the Data into R
  unscaled<-read.dta(file="2nd_Gaza_Conflict_verbal_material.dta")

  #summarizing the data
  summary(unscaled)

  #Israeli Defense Foces Twitter Feed
  IDF<-log(unscaled$idf_twitter+.1)
  #Hamas Twiter Feed
  AQB<-log(unscaled$hamas_twitter+.1)
  #Israel 2 Hamas Conflict Intensity
  I2H_V<-log(unscaled$israel_verbal+.1)
  #Hamas 2 Israel Conflict Intensity
  H2I_V<-log(unscaled$hamas_verbal+.1)
  #Egypt Pressure
  Egypt<-log(unscaled$egypt_pressure+.1)
  #US Pressure
  US<-log(unscaled$us_pressure+.1)
  #UN Pressure 
  UN<-log(unscaled$un_pressure+.1)


  
  
##Hashtag data
hashtag_data<-read.csv(file="merged_hashtag.csv" ,head=TRUE,sep=",")
summary(hashtag_data)
gaza_under<-hashtag_data$gaza_under_attack
israel_under<-hashtag_data$israel_under_fire

##Israel Under Fire Predicting Gaza Under Attack
lag2.plot(israel_under, gaza_under, max.lag = 12, corr = TRUE, smooth = TRUE)

##Gaza Under Attack Predicting Israel Under Fire
lag2.plot( gaza_under, israel_under, max.lag = 12, corr = TRUE, smooth = TRUE)

lag2.plot( UN, US, max.lag = 12, corr = TRUE, smooth = TRUE)

##Reading in Hashtag data


###Time Series Plots
plot(ts(unscaled$idf_twitter, frequency=24), ann=FALSE)
title(xlab="Time in Days", ylab="IDF Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$hamas_twitter, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="AQB Twitter Aggress.", cex.lab=1.4)
plot(ts(unscaled$combined_i2h, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="I2H Conflict Intensity", cex.lab=1.4)
plot(ts(unscaled$combined_h2i, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="H2I Conflict Intensity", cex.lab=1.4)
plot(ts(hashtag_data$gaza_under_attack, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#GazaUnderAttack", cex.lab=1.4)
plot(ts(hashtag_data$israel_under_fire, frequency=24), ann=FALSE )
title(xlab="Time in Days", ylab="#IsraelUnderFire", cex.lab=1.4)



f<-cbind(gaza_under, israel_under)

#Decomposing things
plot(decompose(ts(hashtag_data$gaza_under_attack, frequency=24)), xlab="#GazaUnderAttack  (time in days)")
plot(decompose(ts(hashtag_data$israel_under_fire, frequency=24)), xlab="#IsraelUnderFire  (time in days)")

plot(decompose(ts(hashtag_data$gaza_under_attack-hashtag_data$israel_under_fire, frequency=24)), xlab="#GazaUnderAttack  (time in days)")

#Disentangling the effects
gaza_hash_ts<-ts(log(hashtag_data$gaza_under_attack+.1), frequency=24)
israel_hash_ts<-ts(log(hashtag_data$israel_under_fire+.1), frequency=24)

#Decomposed the data
Gaza_Hash_d<-log(hashtag_data$gaza_under_attack+.1)-decompose(gaza_hash_ts)$seasonal
Israel_Hash_d<-log(hashtag_data$israel_under_fire+.1)-decompose(israel_hash_ts)$seasonal

IDF_ts<-ts(IDF, frequency=24)
AQB_ts<-ts(AQB, frequency=24)
I2H_V_ts<-ts(I2H_V, frequency=24)
H2I_V_ts<-ts(H2I_V, frequency=24)
Egypt_ts<-ts(Egypt, frequency=24)
US_ts<-ts(US, frequency=24)
UN_ts<-ts(UN, frequency=24)

###Removing the 24 hours seasonality due the news cycle
IDF_d<-IDF-decompose(IDF_ts)$seasonal
AQB_d<-AQB-decompose(AQB_ts)$seasonal
I2H_V_d<-I2H_V-decompose(I2H_V_ts)$seasonal
H2I_V_d<-H2I_V-decompose(H2I_V_ts)$seasonal
Egypt_d<-Egypt-decompose(Egypt_ts)$seasonal
US_d<-US-decompose(US_ts)$seasonal
UN_d<-UN-decompose(UN_ts)$seasonal



plot(Gaza_Hash_d)
plot(Israel_Hash_d)
#Non_Decomposed_data
Gaza_Hash<-log(hashtag_data$gaza_under_attack+.1)
Israel_Hash<-log(hashtag_data$israel_under_fire+.1)

plot(ts(Gaza_Hash))
plot(ts(Israel_Hash))

##Adding seasonal
seasonal_dummies<-ts(hashtag_data$peak_hours)


#Joining the time series
israel_gaza<-cbind(H2I_V, I2H_V, IDF, AQB, UN, Egypt, US, Gaza_Hash_d, Israel_Hash_d)




##Full Data (not adjusted for seasonality)
second_gaza<-ts(israel_gaza)


#Variable Lag Test
var.lag.specification(second_gaza,lagmax=12)

#Granger Test
granger.test(second_gaza, 5)
summary(lm(Israel_Hash~seasonal_dummies))

##Restriction A0


##Hashtag IDF Only

hamas_i<-      c(1,1,1,1,0,0,0,0,1)
israel_i<-     c(0,1,1,1,0,0,0,1,0)
idf_i<-        c(0,1,1,1,0,0,0,0,1)
aqb_i<-        c(1,1,1,1,0,0,0,1,0)
un_i<-         c(0,0,0,0,1,0,0,0,0)
egypt_i<-      c(0,0,0,0,0,1,0,0,0)
us_i<-         c(0,0,0,0,0,0,1,0,0)
gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1)
israel_hash_i<-c(0,0,1,0,0,0,0,1,1)

hashtag_idf<-rbind(hamas_i,israel_i,idf_i,aqb_i, un_i,egypt_i, us_i, gaza_hash_i, israel_hash_i)



####Running the BSVAR#####





###IDF Hashtag###

set.seed(67986)
hashtag_idf_second_gaza.bvar <- szbsvar(second_gaza,p=5, lambda0=0.8,
lambda1=0.25, lambda3=2,lambda4=0.5, lambda5=0.25, mu5=0, mu6=0, qm=4, ident=hashtag_idf)

##Getting the Sign
sign.hashtag_idf <- ifelse(sign(diag(hashtag_idf_second_gaza.bvar$A0.mode))==-1, -1, 1)
sign.hashtag_idf

 
###Simulating the Posteriors of A0 10000 Burn In
A0.posterior_hashtag_idf<- gibbs.A0(hashtag_idf_second_gaza.bvar, 10000, 50000)


###Log Marginal Density to beat -3843.722####
# hamas_i<-      c(1,1,1,1,0,0,0,0,1) #
# israel_i<-     c(0,1,1,1,0,0,0,1,0) #
# idf_i<-        c(0,1,1,1,0,0,0,0,1) #
# aqb_i<-        c(1,1,1,1,0,0,0,1,0) #
# un_i<-         c(0,0,0,0,1,0,0,0,0) #
# egypt_i<-      c(0,0,0,0,0,1,0,0,0) #
# us_i<-         c(0,0,0,0,0,0,1,0,0) #
# gaza_hash_i<-  c(0,0,0,1,0,0,0,1,1) #
# israel_hash_i<-c(0,0,1,0,0,0,0,1,1) #

fit_hashtag_idf<- posterior.fit(hashtag_idf_second_gaza.bvar, A0.posterior_hashtag_idf)
print(fit_hashtag_idf)


dfev(hashtag_idf_second_gaza.bvar, A0 =hashtag_idf, 12)


bsvar_hashtag_idf<- mc.irf(hashtag_idf_second_gaza.bvar, nsteps=12, A0.posterior=A0.posterior_hashtag_idf, sign.list=sign.hashtag_idf)
plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84,0.95))



###IRF plots###
#Shock: H2I, Response: I2H ,2

h2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,2]
h2i_irf
#Cumulative IRF
apply(h2i_irf,2,cumsum)

#Shock: I2H, Response: H2I ,10
i2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,10]
i2h_irf
#Cumulative IRF
apply(i2h_irf,2,cumsum)


###Shock IDF: Response H2I ,19

idf2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,19]
idf2h_irf
#Cumulative IRF
apply(idf2h_irf,2,cumsum)



###Shock IDF, Response AQB, 22

idf2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,22]
idf2aqb_irf
#Cumulative IRF
apply(idf2aqb_irf,2,cumsum)


### Shock AQB, Response I2H, 29

aqb2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,29]
aqb2i_irf
#Cumulative IRF
apply(aqb2i_irf,2,cumsum)

##Shock AQB, Response IDF, 30

aqb2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,30]
aqb2idf_irf
#Cumulative IRF
apply(aqb2idf_irf,2,cumsum)




### Shock Gaza Under Attack, Response H2I ,64

gaza2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,64]
gaza2h_irf
#Cumulative IRF
apply(gaza2h_irf,2,cumsum)


### Shock Gaza Under Attack, Response  I2H , 65

gaza2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,65]
gaza2i_irf
#Cumulative IRF
apply(gaza2i_irf,2,cumsum)


###Shock Israel Under Fire, Response H2I , 73

israel2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,73]
israel2h_irf
#Cumulative IRF
apply(israel2h_irf,2,cumsum)


###Shock Israel Under Fire, Response I2H, 74
israel2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,74]
israel2i_irf
#Cumulative IRF
apply(israel2i_irf,2,cumsum)



###Shock Gaza Under Attack, Response IDF, 66
gaza2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,66]
gaza2idf_irf
#Cumulative IRF
apply(gaza2idf_irf,2,cumsum)



###Shock Gaza Under Attack, Response AQB, 67
gaza2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,67]
gaza2aqb_irf
#Cumulative IRF
apply(gaza2aqb_irf,2,cumsum)



###Shock Israel Under Fire, Response IDF, 75
israel2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,75]
israel2idf_irf
#Cumulative IRF
apply(israel2idf_irf,2,cumsum)


###Shock Israel Under Fire, Response IDF, 76
israel2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,76]
israel2aqb_irf
#Cumulative IRF
apply(israel2aqb_irf,2,cumsum)



##Shock H2I, Response #Gaza Under Attack ,8
h2gaza_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,8]
h2gaza_irf
#Cumulative IRF
apply(h2gaza_irf,2,cumsum)



##Shock H2I, Response #Israel Under Fire ,9
h2israel_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,9]
h2israel_irf
#Cumulative IRF
apply(h2israel_irf,2,cumsum)


##Shock I2H, Response #Gaza Under Attack ,17
i2gaza_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,17]
i2gaza_irf
#Cumulative IRF
apply(i2gaza_irf,2,cumsum)


##Shock I2H, Response #Israel Under Fire ,18
i2israel_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,18]
i2israel_irf
#Cumulative IRF
apply(i2israel_irf,2,cumsum)


##Shock IDF, Response #Gaza Under Attack ,26
idf2gaza_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,26]
idf2gaza_irf
#Cumulative IRF
apply(i2gaza_irf,2,cumsum)

##Shock IDF, Response #Israel Under Fire ,27
idf2israel_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,27]
idf2israel_irf
#Cumulative IRF
apply(idf2israel_irf,2,cumsum)


##Shock AQB, Response #Gaza Under Attack ,35
aqb2gaza_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,35]
aqb2gaza_irf
#Cumulative IRF
apply(aqb2gaza_irf,2,cumsum)


##Shock AQB, Response #Israel Under Fire ,36
aqb2israel_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,36]
aqb2israel_irf
#Cumulative IRF
apply(aqb2israel_irf,2,cumsum)



##Shock #Gaza Under Attack, Response #Israel Under Fire ,72
gaza2israel_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,72]
gaza2israel_irf
#Cumulative IRF
apply(gaza2israel_irf,2,cumsum)

##Shock #Israel Under Fire, Response #Gaza Under Attack ,80
israel2gaza_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,80]
israel2gaza_irf
#Cumulative IRF
apply(israel2gaza_irf,2,cumsum)



###Shock UN, Response H2I, 37
un2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,37]
un2h_irf
#Cumulative IRF
apply(un2h_irf,2,cumsum)


###Shock UN, Response H2I, 38
un2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,38]
un2i_irf
#Cumulative IRF
apply(un2i_irf,2,cumsum)


###Shock UN, Response IDF, 39
un2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,39]
un2idf_irf
#Cumulative IRF
apply(un2idf_irf,2,cumsum)


###Shock UN, Response AQB, 40
un2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,40]
un2aqb_irf
#Cumulative IRF
apply(un2aqb_irf,2,cumsum)

###Shock Egypt, Response H2I, 46
egypt2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,46]
egypt2h_irf
#Cumulative IRF
apply(egypt2h_irf,2,cumsum)


###Shock Egypt, Response I2H, 47
egypt2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,47]
egypt2i_irf
#Cumulative IRF
apply(egypt2i_irf,2,cumsum)


###Shock Egypt, Response IDF, 48
egypt2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,48]
egypt2idf_irf
#Cumulative IRF
apply(egypt2idf_irf,2,cumsum)


###Shock Egypt, Response AQB, 49
egypt2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,49]
egypt2aqb_irf
#Cumulative IRF
apply(egypt2aqb_irf,2,cumsum)


###Shock US, Response H2I, 55
us2h_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,55]
us2h_irf
#Cumulative IRF
apply(us2h_irf,2,cumsum)


###Shock US, Response I2H, 56
us2i_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,56]
us2i_irf
#Cumulative IRF
apply(us2i_irf,2,cumsum)


###Shock US, Response IDF, 57
us2idf_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,57]
us2idf_irf
#Cumulative IRF
apply(us2idf_irf,2,cumsum)


###Shock US, Response AQB, 58
us2aqb_irf<-plot(bsvar_hashtag_idf, probs=c(0.05,0.16,0.84, 0.95))$responses[,,58]
us2aqb_irf
#Cumulative IRF
apply(us2aqb_irf,2,cumsum)


