# File-Name:       untitled                
# Date:            2013-04-28                                
# Author:          Thomas Zeitzoff                                      
# Purpose:        
# Data Used:
# Packages Used:              
# Output File:    
# Data Output: 
# Machine:		Thomas Zeitzoff's mac

require("reshape")
require("ggplot2")
  require(quantmod)
  library(astsa)

  library(foreign)
  library(mFilter)
  library(MASS)
  library(tseries)
  library(urca)
  library(MSBVAR)


  ###Reading the Data into R
  unscaled<-read.dta(file="2nd_Gaza_Conflict.dta")

  #summarizing the data
  summary(unscaled)

  #Israeli Defense Foces Twitter Feed
  IDF<-unscaled$idf_twitter
  #Hamas Twiter Feed
  AQB<-unscaled$hamas_twitter
  #Israel 2 Hamas Conflict Intensity
  I2H<-unscaled$combined_i2h
  #Hamas 2 Israel Conflict Intensity
  H2I<-unscaled$combined_h2i
  #Egypt Attention
  Egypt<-unscaled$egypt_pressure
  #US Attention
  US<-unscaled$us_pressure
  #UN Attention 
  UN<-unscaled$un_pressure
  ##Hashtag data
  hashtag_data<-read.csv(file="merged_hashtag.csv" ,head=TRUE,sep=",")
  summary(hashtag_data)
  GazaUnderAttack<-hashtag_data$gaza_under_attack
  IsraelUnderFire<-hashtag_data$israel_under_fire
  
  ##Create the hourly sequence
 hour<- seq(from=as.POSIXct("2012-11-14 12:00", tz="UTC"),
       to=as.POSIXct("2012-11-21 22:00", tz="IST"),
       by="hour")
   
     
israel_hamas<-data.frame(I2H,H2I,hour)

       library(ggplot2)
       library(reshape2)
       theme_set(theme_grey(base_size = 22))
       melt_israel_hamas <- melt(israel_hamas,id="hour")
       conflict_plot=qplot(hour, value, data = melt_israel_hamas, geom = "line", group = variable) +
         facet_grid(variable ~ ., scale = "fixed")
      conflict_plot +xlab("") +ylab("Conflict Intensity")

twitter<-data.frame(IDF,AQB,hour)

 melt_twitter<- melt(twitter,id="hour")
twitter_plot=qplot(hour, value, data = melt_twitter, geom = "line", group = variable) +
   facet_grid(variable ~ ., scale = "fixed")
twitter_plot  +xlab("")+ ylab("Communication Aggression") 

mediator<-data.frame(UN,Egypt, US,hour)

 melt_mediator<- melt(mediator,id="hour")
mediator_plot=qplot(hour, value, data = melt_mediator, geom = "line", group = variable) +
   facet_grid(variable ~ ., scale = "fixed")
mediator_plot +xlab("") + ylab("Mediator Attention") 

hashtag<-data.frame(IsraelUnderFire, GazaUnderAttack,hour)
 melt_hashtag<- melt(hashtag,id="hour")
hashtag_plot=qplot(hour, value, data = melt_hashtag, geom = "line", group = variable) +
   facet_grid(variable ~ ., scale = "fixed")
hashtag_plot+ xlab("") +ylab("Hashtag Mentions") 

###Cumulative IRF Plots###

#Conflict Plots

##Plot 1 (IDF=>H2I, AQB;  AQB=>I2H, IDF)

x_location_idf<-c(4, 9)
x_location_aqb<-c(15, 20)

#IDF IRF Data Info
cumulative_irf_idf<-c(-0.13,0.22)*100
lower_68_idf<-c(-0.17,0.16)*100
upper_68_idf<-c(-0.09, 0.27)*100
lower_90_idf<-c(-0.50,-0.38)*100
upper_90_idf<-c( 0.20,0.88)*100

#AQB IRF Data Info
cumulative_irf_aqb<-c( 1.27, -0.04 )*100
lower_68_aqb<-c( 0.94, -0.46 )*100
upper_68_aqb<-c(1.87,0.39)*100
lower_90_aqb<-c( -1.68, -2.18 )*100
upper_90_aqb<-c(5.02, 2.11)*100


####Getting the plotting ready and plotting the point estimates
par(oma=c(1,1,1,1))  # all sides have 3 lines of space  
plot(x_location_idf, cumulative_irf_idf , cex=1.5, pch=21, ylim=c(-500,500),xlim=c(0,24), xlab="", ylab="% Change After 12 Hours", xaxt="n", cex.lab=1.5, cex.axis=1.3)
##Adding an X-axis
segments(-2,0,26,0,lty=1, lwd=.6)

points(x_location_aqb,cumulative_irf_aqb,cex=1.5, pch=22, col=c('red'))

#Plotting the arrows 68 arrows

##IDF

#90
arrows(x_location_idf,lower_90_idf, x_location_idf,upper_90_idf, col=c("darkgrey"), angle=90, code=3, length=0.05, lty=1, lwd=1.5)
#68
segments(x_location_idf,lower_68_idf, x_location_idf,upper_68_idf, col=c("black"), lty=1, lwd=4.5)
##AQB

#90
arrows(x_location_aqb,lower_90_aqb, x_location_aqb,upper_90_aqb, col=c("darkgrey"), angle=90, code=3, length=0.05,  lty=1, lwd=1.5)
#68
segments(x_location_aqb,lower_68_aqb, x_location_aqb,upper_68_aqb, col=c("red"),  lty=1, lwd=4.5)



legend(0, 500,c("Shock in IDF", "Shock in AQB"), cex=1.3, col=c("black","red"), 
pch=21:22, lty=1, lwd=2)
axis(1, at=c(4,9,15,20), lab=c("H2I","AQB","I2H","IDF"), cex.axis=1.5)


####Hashtag Effects

##Plot 2 (#Gaza=>H2I, I2H, IDF, AQB, #Israel;  Israel=> H2I, I2H, IDF, AQB, #Gaza)
x_location_israel<-c(4, 8, 12, 16, 20)
x_location_gaza<-c(5, 9, 13, 17, 24)

#Gaza Under Attack IRF Data Info
cumulative_irf_gaza<-c(-0.56,-1.77,0.62,-0.39, 1.31)*100
lower_68_gaza<-c(-0.66, -2.06,0.46, -0.57, 0.60 )*100
upper_68_gaza<-c(-0.46, -1.48, 0.78, -0.20, 2.16)*100
lower_90_gaza<-c(-1.12,-3.65, -0.16, -1.42, -0.86)*100
upper_90_gaza<-c(-0.08, 0.00, 1.47,  0.63, 3.67 )*100

#Israel Under Fire IRF Data Info
cumulative_irf_israel<-c(-0.33, -0.98, 0.69, 0.12, 0.23 )*100
lower_68_israel<-c(-0.43,-1.12,0.48, -0.001,0.05 )*100
upper_68_israel<-c(-0.25, -0.84, 0.95,0.27, 0.40)*100
lower_90_israel<-c(-0.82, -2.20, -0.24,-0.67,-0.27)*100
upper_90_israel<-c(0.14, -0.03, 1.88, 0.98, 0.92 )*100


####Getting the plotting ready and plotting the point estimates
par(oma=c(1,1,1,1))  # all sides have 3 lines of space  
plot(x_location_gaza, cumulative_irf_gaza , cex=1.5, pch=21, ylim=c(-500,500),xlim=c(0,27), xlab="", 
ylab="% Change After 12 Hours", xaxt="n", cex.lab=1.5, cex.axis=1.3)
##Adding an X-axis
segments(-2,0,36.5,0,lty=1, lwd=.6)

points(x_location_israel,cumulative_irf_israel,cex=1.5, pch=22, col=c('red'))

#Plotting the arrows 68 arrows

##IDF

#90
arrows(x_location_gaza,lower_90_gaza, x_location_gaza,upper_90_gaza, col=c("darkgrey"), angle=90, code=3, length=0.05, lty=1, lwd=1.5)
#68
segments(x_location_gaza,lower_68_gaza, x_location_gaza,upper_68_gaza, col=c("black"), lty=1, lwd=4.5)
##AQB

#90
arrows(x_location_israel,lower_90_israel, x_location_israel,upper_90_israel, col=c("darkgrey"), angle=90, code=3, length=0.05,  lty=1, lwd=1.5)
#68
segments(x_location_israel,lower_68_israel, x_location_israel,upper_68_israel, col=c("red"),  lty=1, lwd=4.5)



legend(0, 500,c("Shock in #Gaza", "Shock in #Israel"), cex=1.3, col=c("black","red"), 
pch=21:22, lty=1, lwd=2)
axis(1, at=c(4.5, 8.5 ,12.5, 16.5, 20, 24), lab=c("H2I", "I2H", "IDF", "AQB", "#Gaza", "#Israel"), cex.axis=1.35)
 



####Mediator Effects

##Plot 3 UN =>I2H, H2I, IDF, AQB) (#Egypt =>I2H, H2I, IDF, AQB) (#US =>I2H, H2I, IDF, AQB)
x_location_un<-   c(4, 10, 16, 22)
x_location_egypt<-c(5, 11, 17, 23)
x_location_us<-   c(6, 12, 18, 24)

#UN IRF Data Info order is I2H, H2I, IDF, AQB
cumulative_irf_un<-c(0.54, 0.34, 0.02 , -0.12)*100
lower_68_un<-c(0.54,0.34, 0.02, -0.12)*100
upper_68_un<-c(0.54,0.34, 0.02, -0.12)*100
lower_90_un<-c(0.54, 0.34,0.02, -0.12)*100
upper_90_un<-c(0.87, 0.36 ,0.02, -0.12)*100

#Egypt IRF Data Info order is I2H, H2I, IDF, AQB
cumulative_irf_egypt<-c(0.57, 0.15, -0.02, -0.28)*100
lower_68_egypt<-c(0.57,0.15,-0.02, -0.28)*100
upper_68_egypt<-c(0.57, 0.15,-0.02,-0.28)*100
lower_90_egypt<-c(0.57, 0.15,-0.02,-0.29)*100
upper_90_egypt<-c(0.92, 0.15,-0.02,-0.28)*100

#US IRF Data Info order is I2H, H2I, IDF, AQB
cumulative_irf_us<-c(0.57, 0.50,0.03, -0.17)*100
lower_68_us<-c(0.57,0.50,0.03, -0.17)*100
upper_68_us<-c(0.57, 0.50,0.03,-0.17)*100
lower_90_us<-c(0.57, 0.50,0.03,--0.17)*100
upper_90_us<-c(0.87, 0.56,0.10,-0.17)*100


####Getting the plotting ready and plotting the point estimates
par(oma=c(1,1,1,1))  # all sides have 3 lines of space  
plot(x_location_un, cumulative_irf_un , cex=1.5, pch=21, ylim=c(-100,100),xlim=c(0,28), xlab="", 
ylab="% Change After 12 Hours", xaxt="n", cex.lab=1.5, cex.axis=1.3)
##Adding an X-axis
segments(-2.5,0,30.5,0,lty=1, lwd=.6)

###Adding Egypt
points(x_location_egypt,cumulative_irf_egypt,cex=1.5, pch=22, col=c('red'))

###Adding us
points(x_location_us,cumulative_irf_us,cex=1.5, pch=25, col=c('blue'))

#Plotting the arrows 68 arrows

##UN

#90
arrows(x_location_un,lower_90_un, x_location_un,upper_90_un, col=c("darkgrey"), angle=90, code=3, length=0.05, lty=1, lwd=1.5)
#68
segments(x_location_un,lower_68_un, x_location_un,upper_68_un, col=c("black"), lty=1, lwd=4.5)

##Egypt

#90
arrows(x_location_egypt,lower_90_egypt, x_location_egypt,upper_90_egypt, col=c("darkgrey"), angle=90, code=3, length=0.05,  lty=1, lwd=.1.5)
#68
segments(x_location_egypt,lower_68_egypt, x_location_egypt,upper_68_egypt, col=c("red"),  lty=1, lwd=4.5)

##us

#90
arrows(x_location_us,lower_90_us, x_location_us,upper_90_us, col=c("darkgrey"), angle=90, code=3, length=0.05,  lty=1, lwd=1.5)
#68
segments(x_location_us,lower_68_us, x_location_us,upper_68_us, col=c("blue"),  lty=1, lwd=4.5)




legend(18, 100,c("Shock in UN", "Shock in Egypt", "Shocks in US"), cex=1.3, col=c("black","red", "blue"), 
pch=c(21,22,25), lty=1, lwd=2)
axis(1, at=c(5,11,17,23), lab=c("H2I", "I2H", "IDF", "AQB"), cex.axis=1.5)
 
mtext("Response Variable", side = 1, line=-1, cex=1.7, outer=TRUE)


